Package: ggcube
Type: Package
Title: 3D Plotting with 'ggplot2'
Version: 0.2.0
Authors@R: 
    person("Matthew", "Kling", , "mattkling@berkeley.edu", 
    role = c("aut", "cre", "cph"))
Description: A 'ggplot2' extension for creating 3D figures.
    Provides 3D geoms, stats, and a coord_3d() coordinate
    system supporting rotation, perspective, and lighting.
License: MIT + file LICENSE
Encoding: UTF-8
LazyData: true
URL: https://github.com/matthewkling/ggcube,
        https://matthewkling.github.io/ggcube/
BugReports: https://github.com/matthewkling/ggcube/issues
Depends: R (>= 3.5), ggplot2
Imports: dplyr, tidyr, stringr, scales, rlang, grid, lifecycle,
        labeling, purrr, magrittr, polyclip, isoband, systemfonts,
        htmlwidgets
Suggests: alphashape3d, av, base64enc, geometry, gifski, gtable, knitr,
        MASS, mgcv, patchwork, progress, ragg, rmarkdown, rstudioapi,
        shiny, testthat (>= 3.0.0)
Config/testthat/edition: 3
VignetteBuilder: knitr
Config/Needs/website: rmarkdown
Config/roxygen2/version: 8.0.0
NeedsCompilation: no
Packaged: 2026-07-21 13:50:13 UTC; matthewkling
Author: Matthew Kling [aut, cre, cph]
Maintainer: Matthew Kling <mattkling@berkeley.edu>
Repository: CRAN
Date/Publication: 2026-07-21 14:30:02 UTC
Built: R 4.6.1; ; 2026-07-21 17:06:38 UTC; unix
