# Generated by roxygen2: do not edit by hand

S3method(knitr::knit_print,gif_3d)
S3method(knitr::knit_print,video_3d)
S3method(print,gif_3d)
S3method(print,light)
S3method(print,video_3d)
export(aes)
export(anim_save_3d)
export(animate_3d)
export(annotate_3d)
export(av_renderer_3d)
export(camera_facing)
export(coord_3d)
export(element_rect)
export(file_renderer_3d)
export(geom_bar_3d)
export(geom_col_3d)
export(geom_contour_3d)
export(geom_density_3d)
export(geom_distributions_3d)
export(geom_function_3d)
export(geom_hull_3d)
export(geom_path_3d)
export(geom_point_3d)
export(geom_polygon_3d)
export(geom_ridgeline_3d)
export(geom_segment_3d)
export(geom_smooth_3d)
export(geom_surface_3d)
export(geom_text_3d)
export(geom_voxel_3d)
export(gifski_renderer_3d)
export(guide_colorbar_3d)
export(guide_legend_3d)
export(light)
export(orbit3dOutput)
export(orbit_3d)
export(position_on_face)
export(renderOrbit3d)
export(scale_z_continuous)
export(scale_z_discrete)
export(stat_bar_3d)
export(stat_col_3d)
export(stat_contour_3d)
export(stat_density_3d)
export(stat_distributions_3d)
export(stat_function_3d)
export(stat_hull_3d)
export(stat_identity_3d)
export(stat_path_3d)
export(stat_point_3d)
export(stat_segment_3d)
export(stat_smooth_3d)
export(stat_surface_3d)
export(stat_text_3d)
export(stat_voxel_3d)
export(text_outlines)
export(zlim)
import(dplyr)
import(ggplot2)
importFrom(ggplot2,resolution)
importFrom(grDevices,as.raster)
importFrom(grDevices,chull)
importFrom(grDevices,col2rgb)
importFrom(grDevices,hsv)
importFrom(grDevices,rgb)
importFrom(grDevices,rgb2hsv)
importFrom(grid,convertHeight)
importFrom(grid,convertWidth)
importFrom(grid,gpar)
importFrom(grid,grobHeight)
importFrom(grid,grobTree)
importFrom(grid,grobWidth)
importFrom(grid,nullGrob)
importFrom(grid,polygonGrob)
importFrom(grid,rectGrob)
importFrom(grid,segmentsGrob)
importFrom(grid,textGrob)
importFrom(isoband,isobands)
importFrom(labeling,extended)
importFrom(lifecycle,deprecate_soft)
importFrom(lifecycle,is_present)
importFrom(magrittr,"%>%")
importFrom(polyclip,polyclip)
importFrom(polyclip,polysimplify)
importFrom(purrr,map_dfr)
importFrom(rlang,"%||%")
importFrom(scales,extended_breaks)
importFrom(scales,rescale)
importFrom(stats,ave)
importFrom(stats,density)
importFrom(stats,dnorm)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,loess)
importFrom(stats,na.omit)
importFrom(stats,predict)
importFrom(stats,setNames)
importFrom(stats,weighted.mean)
importFrom(stringr,str_remove)
importFrom(systemfonts,glyph_outline)
importFrom(systemfonts,match_fonts)
importFrom(systemfonts,shape_string)
importFrom(tidyr,expand_grid)
importFrom(tidyr,gather)
importFrom(tidyr,unite)
importFrom(utils,modifyList)
