#' Sphere surface points
#'
#' A toy data set representing points on a sphere surface,
#' useful for testing hull functions
#'
#' @format ## `sphere_points`
#' A data frame with 200 rows and 3 columns (x, y, and z)
"sphere_points"


#' Volcano terrain data
#'
#' A terrain data set representing elevational variation over
#' an x-y grid.
#'
#' @format ## `mountain`
#' A data frame with 1290 rows and 3 columns (x, y, and z)
#' @source derived from the `datasets::volcano` data set
"mountain"
