% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/shared-docs.R
\name{ridgeline_params}
\alias{ridgeline_params}
\title{Shared ridgeline params}
\arguments{
\item{direction}{Direction of ridges:
\describe{
\item{"x"}{One ridge per unique x value; ridge varies in y (default)}
\item{"y"}{One ridge per unique y value; ridge varies in x}
}}

\item{base}{Z-value for ridge polygon bottoms. If NULL, uses min(z).}
}
\description{
Shared ridgeline params
}
\keyword{internal}
