% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/label-rendering.R
\name{makeContent.ggcube_axis_furniture}
\alias{makeContent.ggcube_axis_furniture}
\title{Resolve 3D axis labels and titles at draw time}
\usage{
\method{makeContent}{ggcube_axis_furniture}(x)
}
\arguments{
\item{x}{A \code{ggcube_axis_furniture} gTree.}
}
\value{
The gTree with its children populated.
}
\description{
Resolve 3D axis labels and titles at draw time
}
\keyword{internal}
